@@ -27,6 +27,7 @@ def _commit(cls):
     cursor.connection.commit()
 
 def _key_by_table(db, table, cursor):
+    db = db.dbcnf['db']
     db_table = '%s.%s'%(db , table)
     key = [ db_table ]
 
@@ -66,13 +67,13 @@ class _Model(type):
 
         if base0 is ModelMc:
             new_class.__key__ = "%s'%%s"%(_key_by_table(
-                db.dbcnf['db'], name, q
+                db, name, q
             ).replace('%', '%%'))
         return new_class
 
 def _delete(self):
     Query.execute(
-        'DELETE FROM %s WHERE %%s=%%s' % self.__table__ ,
+        'DELETE FROM %s WHERE id=%%s' % self.__table__ ,
         self.id,
         self.__db__
     )
